@@ -12,6 +12,7 @@ class MultiNamespaceReflector(NamespacedResourceReflector):
     """We need to remove the namespace from all the list_method_name
     calls.  That requires, unfortunately, a lot of code duplication.
     """
+
     list_method_omit_namespace = True
 
     def _list_and_update(self):
@@ -28,8 +29,13 @@ class MultiNamespaceReflector(NamespacedResourceReflector):
         )
         # This is an atomic operation on the dictionary!
         initial_resources = json.loads(initial_resources.read())
-        self.resources = {p["metadata"]["name"]: p for p in initial_resources["\
-items"]}
+        self.resources = {
+            p["metadata"]["name"]: p
+            for p in initial_resources[
+                "\
+items"
+            ]
+        }
         # return the resource version so we can hook up a watch
         return initial_resources["metadata"]["resourceVersion"]
 
@@ -61,13 +67,15 @@ items"]}
             selectors.append("label selector=%r" % self.label_selector)
         if self.field_selector:
             selectors.append("field selector=%r" % self.field_selector)
-        log_selector = ', '.join(selectors)
+        log_selector = ", ".join(selectors)
 
         cur_delay = 0.1
 
         self.log.info(
             "watching for %s with %s in namespace %s",
-            self.kind, log_selector, self.namespace,
+            self.kind,
+            log_selector,
+            self.namespace,
         )
         while True:
             start = time.monotonic()
@@ -78,24 +86,23 @@ items"]}
                     # signal that we've loaded our initial data
                     self.first_load_future.set_result(None)
                 watch_args = {
-                    'label_selector': self.label_selector,
-                    'field_selector': self.field_selector,
-                    'resource_version': resource_version,
+                    "label_selector": self.label_selector,
+                    "field_selector": self.field_selector,
+                    "resource_version": resource_version,
                 }
                 if self.request_timeout:
                     # set network receive timeout
-                    watch_args['_request_timeout'] = self.request_timeout
+                    watch_args["_request_timeout"] = self.request_timeout
                 if self.timeout_seconds:
                     # set watch timeout
-                    watch_args['timeout_seconds'] = self.timeout_seconds
+                    watch_args["timeout_seconds"] = self.timeout_seconds
                 method = partial(
-                    getattr(self.api, self.list_method_name), _preload_content=False)
+                    getattr(self.api, self.list_method_name),
+                    _preload_content=False,
+                )
                 # in case of timeout_seconds, the w.stream just exits (no exception thrown)
                 # -> we stop the watcher and start a new one
-                for watch_event in w.stream(
-                    method,
-                    **watch_args
-                ):
+                for watch_event in w.stream(method, **watch_args):
                     # Remember that these events are k8s api related WatchEvents
                     # objects, not k8s Event or Pod representations, they will
                     # reside in the WatchEvent's object field depending on what
@@ -104,8 +111,8 @@ items"]}
                     # ref: https://kubernetes.io/docs/reference/generated/kubernetes-api/v1.16/#watchevent-v1-meta
                     # ref: https://kubernetes.io/docs/reference/generated/kubernetes-api/v1.16/#event-v1-core
                     cur_delay = 0.1
-                    resource = watch_event['object']
-                    if watch_event['type'] == 'DELETED':
+                    resource = watch_event["object"]
+                    if watch_event["type"] == "DELETED":
                         # This is an atomic delete operation on the dictionary!
                         self.resources.pop(resource["metadata"]["name"], None)
                     else:
@@ -118,25 +125,29 @@ items"]}
                     if watch_duration >= self.restart_seconds:
                         self.log.debug(
                             "Restarting %s watcher after %i seconds",
-                            self.kind, watch_duration,
+                            self.kind,
+                            watch_duration,
                         )
                         break
             except ReadTimeoutError:
                 # network read time out, just continue and restart the watch
                 # this could be due to a network problem or just low activity
                 self.log.warning(
-                    "Read timeout watching %s, reconnecting", self.kind)
+                    "Read timeout watching %s, reconnecting", self.kind
+                )
                 continue
             except Exception:
                 cur_delay = cur_delay * 2
                 if cur_delay > 30:
                     self.log.exception(
-                        "Watching resources never recovered, giving up")
+                        "Watching resources never recovered, giving up"
+                    )
                     if self.on_failure:
                         self.on_failure()
                     return
                 self.log.exception(
-                    "Error when watching resources, retrying in %ss", cur_delay)
+                    "Error when watching resources, retrying in %ss", cur_delay
+                )
                 time.sleep(cur_delay)
                 continue
             finally:
@@ -156,9 +167,10 @@ items"]}
         start of program initialization (when the singleton is being created),
         and not afterwards!
         """
-        if hasattr(self, 'watch_thread'):
+        if hasattr(self, "watch_thread"):
             raise ValueError(
-                'Thread watching for resources is already running')
+                "Thread watching for resources is already running"
+            )
 
         self._list_and_update()
         self.watch_thread = threading.Thread(target=self._watch_and_update)
@@ -172,4 +184,4 @@ class MultiNamespacePodReflector(MultiNamespaceReflector, PodReflector):
 
 
 class MultiNamespaceEventReflector(MultiNamespaceReflector, EventReflector):
-    list_method_name = 'list_event_for_all_namespaces'
+    list_method_name = "list_event_for_all_namespaces"
